@@ -20,6 +20,8 @@
 #include <gtk/gtk.h>
 #include <glib/gprintf.h>
 
+#include <glib/gi18n-lib.h> /* Declares _(). */
+
 #include <hildon/hildon.h>
 #include <libhildondesktop/libhildondesktop.h>
 #include <hildon-fm-2/hildon/hildon-file-chooser-dialog.h>
@@ -182,7 +184,7 @@ settings_dialog_new (GpsDataLoggerWidget * self)
     GtkWidget *selector;
     GtkWidget *panarea;
 
-    dialog = gtk_dialog_new_with_buttons ("GPS Data Logger Widget Settings",
+    dialog = gtk_dialog_new_with_buttons (_("GPS Data Logger Widget Settings"),
 					  NULL, /* parent */
 					  GTK_DIALOG_DESTROY_WITH_PARENT |
 					  GTK_DIALOG_NO_SEPARATOR,
@@ -191,14 +193,14 @@ settings_dialog_new (GpsDataLoggerWidget * self)
     gtk_widget_set_size_request (dialog, 800, 350);
     vbox = gtk_vbox_new (FALSE, 0);
     gtk_box_pack_start (GTK_BOX (vbox),
-                        gtk_label_new ("Location Methods"),
+                        gtk_label_new (_("Location Methods")),
                         TRUE, TRUE, 4);
     /* AGNSS */
     self->chk_method_agnss = hildon_check_button_new (HILDON_SIZE_FINGER_HEIGHT);
     hildon_check_button_set_active(HILDON_CHECK_BUTTON(self->chk_method_agnss),
 		    		self->settings->method_agnss);
     gtk_button_set_label (GTK_BUTTON (self->chk_method_agnss),
-                          "Assisted GPS");
+                          _("Assisted GPS"));
     gtk_button_set_alignment (GTK_BUTTON (self->chk_method_agnss),
                               0.0, 0.5);
     gtk_box_pack_start (GTK_BOX (vbox),
@@ -208,7 +210,7 @@ settings_dialog_new (GpsDataLoggerWidget * self)
     hildon_check_button_set_active(HILDON_CHECK_BUTTON(self->chk_method_gnss),
 		    		self->settings->method_gnss);
     gtk_button_set_label (GTK_BUTTON (self->chk_method_gnss),
-                          "GPS");
+                          _("GPS"));
     gtk_button_set_alignment (GTK_BUTTON (self->chk_method_gnss),
                               0.0, 0.5);
     gtk_box_pack_start (GTK_BOX (vbox),
@@ -218,7 +220,7 @@ settings_dialog_new (GpsDataLoggerWidget * self)
     hildon_check_button_set_active(HILDON_CHECK_BUTTON(self->chk_method_acwp),
 		    		self->settings->method_acwp);
     gtk_button_set_label (GTK_BUTTON (self->chk_method_acwp),
-                          "Assisted, using cellular base stations");
+                          _("Assisted, using cellular base stations"));
     gtk_button_set_alignment (GTK_BUTTON (self->chk_method_acwp),
                               0.0, 0.5);
     gtk_box_pack_start (GTK_BOX (vbox),
@@ -229,14 +231,14 @@ settings_dialog_new (GpsDataLoggerWidget * self)
     hildon_check_button_set_active(HILDON_CHECK_BUTTON(self->chk_method_cwp),
 		    		self->settings->method_cwp);
     gtk_button_set_label (GTK_BUTTON (self->chk_method_cwp),
-                          "Center of the current country");
+                          _("Center of the current country"));
     gtk_button_set_alignment (GTK_BUTTON (self->chk_method_cwp),
                               0.0, 0.5);
     gtk_box_pack_start (GTK_BOX (vbox),
                         self->chk_method_cwp, TRUE, TRUE, 4);
     /* Interval */
     gtk_box_pack_start (GTK_BOX (vbox),
-                        gtk_label_new ("Interval"),
+                        gtk_label_new (_("Interval")),
                         TRUE, TRUE, 4);
     /* Interval picker */
     self->pkr_interval = hildon_picker_button_new
@@ -244,24 +246,24 @@ settings_dialog_new (GpsDataLoggerWidget * self)
              HILDON_BUTTON_ARRANGEMENT_VERTICAL);
     gtk_button_set_alignment (GTK_BUTTON (self->pkr_interval), 0.0, 0.5);
     hildon_button_set_title (HILDON_BUTTON (self->pkr_interval),
-                             "Logging interval");
+                             _("Logging interval"));
     selector = hildon_touch_selector_new_text ();
     hildon_touch_selector_append_text(HILDON_TOUCH_SELECTOR (selector),
-                                      " 1 second");
+                                      _(" 1 second"));
     hildon_touch_selector_append_text(HILDON_TOUCH_SELECTOR (selector),
-                                      " 2 seconds");
+                                      _(" 2 seconds"));
     hildon_touch_selector_append_text(HILDON_TOUCH_SELECTOR (selector),
-                                      " 5 seconds");
+                                      _(" 5 seconds"));
     hildon_touch_selector_append_text(HILDON_TOUCH_SELECTOR (selector),
-                                      "10 seconds");
+                                      _("10 seconds"));
     hildon_touch_selector_append_text(HILDON_TOUCH_SELECTOR (selector),
-                                      "20 seconds");
+                                      _("20 seconds"));
     hildon_touch_selector_append_text(HILDON_TOUCH_SELECTOR (selector),
-                                      "30 seconds");
+                                      _("30 seconds"));
     hildon_touch_selector_append_text(HILDON_TOUCH_SELECTOR (selector),
-                                      "60 seconds");
+                                      _("60 seconds"));
     hildon_touch_selector_append_text(HILDON_TOUCH_SELECTOR (selector),
-                                      "120 seconds");
+                                      _("120 seconds"));
     hildon_picker_button_set_selector(HILDON_PICKER_BUTTON
              (self->pkr_interval), HILDON_TOUCH_SELECTOR (selector));
     gtk_box_pack_start (GTK_BOX (vbox),
@@ -270,14 +272,14 @@ settings_dialog_new (GpsDataLoggerWidget * self)
                                       0, self->settings->interval);
     /* Log */
     gtk_box_pack_start (GTK_BOX (vbox),
-                        gtk_label_new ("Log"),
+                        gtk_label_new (_("Log")),
                         TRUE, TRUE, 4);
     /* Log path */
     self->btn_path = hildon_button_new (HILDON_SIZE_FINGER_HEIGHT,
 		                  HILDON_BUTTON_ARRANGEMENT_VERTICAL);
     gtk_button_set_alignment (GTK_BUTTON (self->btn_path), 0.0, 0.5);
     hildon_button_set_title(HILDON_BUTTON(self->btn_path),
-		            "Folder to store the logs");
+		            _("Folder to store the logs"));
     hildon_button_set_value(HILDON_BUTTON(self->btn_path),
 		            self->settings->log_folder);
     gtk_box_pack_start (GTK_BOX (vbox),
@@ -500,10 +502,10 @@ logfile_start(GpsDataLoggerWidget * self)
     if (! (self->file)) {
         hildon_banner_show_informationf(NULL,
                         NULL,
-                        "Could not open \"%s\" for writing!",
+                        _("Could not open \"%s\" for writing!"),
 			path);
 #ifndef __arm__
-	g_print("Could not open logfile for writing, going to IDLE\n");
+	g_print(_("Could not open logfile for writing, going to IDLE\n"));
 #endif
         self->app_state = APP_STATE_IDLE;
         location_gpsd_control_stop(self->control);
@@ -526,7 +528,7 @@ update_status_and_buttons (GpsDataLoggerWidget * self)
 {
 #ifdef DEBUG
     if (self->logfile) {
-        g_fprintf(self->logfile, "%s -- enter (state: %d)\n", __func__, self->app_state);
+        g_fprintf(self->logfile, _("%s -- enter (state: %d)\n"), __func__, self->app_state);
 	fflush(self->logfile);
     }
 #endif
@@ -538,7 +540,7 @@ update_status_and_buttons (GpsDataLoggerWidget * self)
 		self->rec_button_enabled = FALSE;
 		self->stop_button_enabled = TRUE;
 #ifndef __arm__
-		g_print(" starting: loading new icon, disabling rec\n");
+		g_print(_(" starting: loading new icon, disabling rec\n"));
 #endif
 		break;
 	case APP_STATE_RECORDING:
@@ -566,14 +568,14 @@ update_status_and_buttons (GpsDataLoggerWidget * self)
 		self->rec_button_enabled = TRUE;
 		self->stop_button_enabled = FALSE;
 #ifndef __arm__
-		g_print(" idle or default\n");
+		g_print(_(" idle or default\n"));
 #endif
 		break;
     }
     gtk_widget_queue_draw(GTK_WIDGET(self));
 #ifdef DEBUG
     if (self->logfile) {
-        g_fprintf(self->logfile, "%s -- leave\n", __func__);
+        g_fprintf(self->logfile, _("%s -- leave\n"), __func__);
 	fflush(self->logfile);
     }
 #endif
@@ -586,7 +588,7 @@ handle_button_press (GtkWidget *button,
     GpsDataLoggerWidget *self = GPS_DATA_LOGGER_WIDGET (data);
 #ifdef DEBUG
     if (self->logfile) {
-        g_fprintf(self->logfile, "%s -- enter (state: %d)\n", __func__, self->app_state);
+        g_fprintf(self->logfile, _("%s -- enter (state: %d)\n"), __func__, self->app_state);
 	fflush(self->logfile);
     }
 #endif
@@ -595,15 +597,15 @@ handle_button_press (GtkWidget *button,
         if (self->app_state == APP_STATE_IDLE) {
             self->app_state = APP_STATE_STARTING;
 #ifndef __arm__
-	    g_print(" new state: starting\n");
-            g_print("handle_button_press : calling update_status_and_buttons\n");
+	    g_print(_(" new state: starting\n"));
+            g_print(_("handle_button_press : calling update_status_and_buttons\n"));
 #endif
             update_status_and_buttons(self);
 	    /* open a new log file */
 	    logfile_start(self);
 #ifdef DEBUG
     if (self->logfile) {
-        g_fprintf(self->logfile, "%s -- calling location_gpsd_control_start\n", __func__);
+        g_fprintf(self->logfile, _("%s -- calling location_gpsd_control_start\n"), __func__);
 	fflush(self->logfile);
     }
 #endif
@@ -614,8 +616,8 @@ handle_button_press (GtkWidget *button,
 	else if (self->app_state == APP_STATE_RECORDING) {
             self->app_state = APP_STATE_PAUSED;
 #ifndef __arm__
-	    g_print(" new state: paused\n");
-            g_print("handle_button_press : calling update_status_and_buttons\n");
+	    g_print(_(" new state: paused\n"));
+            g_print(_("handle_button_press : calling update_status_and_buttons\n"));
 #endif
             update_status_and_buttons(self);
             location_gpsd_control_stop(self->control);
@@ -623,8 +625,8 @@ handle_button_press (GtkWidget *button,
 	else if (self->app_state == APP_STATE_PAUSED) {
             self->app_state = APP_STATE_STARTING;
 #ifndef __arm__
-	    g_print(" new state: starting, after pause\n");
-            g_print("handle_button_press : calling update_status_and_buttons\n");
+	    g_print(_(" new state: starting, after pause\n"));
+            g_print(_("handle_button_press : calling update_status_and_buttons\n"));
 #endif
             update_status_and_buttons(self);
 	    /* close tarck segment and start a new one,
@@ -638,8 +640,8 @@ handle_button_press (GtkWidget *button,
     } else if (button == self->button_stop) {
 	self->app_state = APP_STATE_STOPPING;
 #ifndef __arm__
-	g_print(" new state: stoping\n");
-        g_print("handle_button_press : calling update_status_and_buttons\n");
+	g_print(_(" new state: stoping\n"));
+        g_print(_("handle_button_press : calling update_status_and_buttons\n"));
 #endif
         update_status_and_buttons(self);
         location_gpsd_control_stop(self->control);
@@ -648,7 +650,7 @@ handle_button_press (GtkWidget *button,
     }
 #ifdef DEBUG
     if (self->logfile) {
-        g_fprintf(self->logfile, "%s -- leave (new state: %d)\n", __func__, self->app_state);
+        g_fprintf(self->logfile, _("%s -- leave (new state: %d)\n"), __func__, self->app_state);
 	fflush(self->logfile);
     }
 #endif
@@ -662,13 +664,13 @@ on_button_release(GtkWidget* widget, GdkEventButton *button_event, gpointer data
 
 #ifdef DEBUG
     if (self->logfile) {
-        g_fprintf(self->logfile, "%s -- enter ", __func__);
+        g_fprintf(self->logfile, _("%s -- enter "), __func__);
         if (widget == GTK_WIDGET(self->background)) {
-	    g_fprintf(self->logfile, " widget: background\n");
+	    g_fprintf(self->logfile, _(" widget: background\n"));
 	} else if (widget == GTK_WIDGET(self->button_rec)) {
-	    g_fprintf(self->logfile, " widget: button_rec\n");
+	    g_fprintf(self->logfile, _(" widget: button_rec\n"));
 	} else if (widget == GTK_WIDGET(self->button_stop)) {
-	    g_fprintf(self->logfile, " widget: button_stop\n");
+	    g_fprintf(self->logfile, _(" widget: button_stop\n"));
 	}
 	fflush(self->logfile);
     }
@@ -688,7 +690,7 @@ on_button_release(GtkWidget* widget, GdkEventButton *button_event, gpointer data
             self->rec_button_enabled) {
 #ifdef DEBUG
                 if (self->logfile) {
-                    g_fprintf(self->logfile, "  calling handle_button_press on background for button_rec\n");
+                    g_fprintf(self->logfile, _("  calling handle_button_press on background for button_rec\n"));
 	            fflush(self->logfile);
 		}
 #endif
@@ -702,7 +704,7 @@ on_button_release(GtkWidget* widget, GdkEventButton *button_event, gpointer data
             self->stop_button_enabled) {
 #ifdef DEBUG
                 if (self->logfile) {
-                    g_fprintf(self->logfile, "  calling handle_button_press on background for button_stop\n");
+                    g_fprintf(self->logfile, _("  calling handle_button_press on background for button_stop\n"));
 	            fflush(self->logfile);
 		}
 #endif
@@ -712,7 +714,7 @@ on_button_release(GtkWidget* widget, GdkEventButton *button_event, gpointer data
 		    self->rec_button_enabled) {
 #ifdef DEBUG
         if (self->logfile) {
-            g_fprintf(self->logfile, "  calling handle_button_press on button_rec for button_rec\n");
+            g_fprintf(self->logfile, _("  calling handle_button_press on button_rec for button_rec\n"));
 	    fflush(self->logfile);
 	}
 #endif
@@ -721,7 +723,7 @@ on_button_release(GtkWidget* widget, GdkEventButton *button_event, gpointer data
 		    self->stop_button_enabled) {
 #ifdef DEBUG
         if (self->logfile) {
-             g_fprintf(self->logfile, "  calling handle_button_press on button_stop for button_stop\n");
+             g_fprintf(self->logfile, _("  calling handle_button_press on button_stop for button_stop\n"));
 	     fflush(self->logfile);
 	}
 #endif
@@ -730,7 +732,7 @@ on_button_release(GtkWidget* widget, GdkEventButton *button_event, gpointer data
     
 #ifdef DEBUG
     if (self->logfile) {
-        g_fprintf(self->logfile, "%s -- leave\n", __func__);
+        g_fprintf(self->logfile, _("%s -- leave\n"), __func__);
 	fflush(self->logfile);
     }
 #endif
@@ -745,13 +747,13 @@ on_button_press(GtkWidget* widget, GdkEventButton *button_event, gpointer data)
 
 #ifdef DEBUG
     if (self->logfile) {
-        g_fprintf(self->logfile, "%s -- enter ", __func__);
+        g_fprintf(self->logfile, _("%s -- enter "), __func__);
         if (widget == GTK_WIDGET(self->background)) {
-	    g_fprintf(self->logfile, " widget: background\n");
+	    g_fprintf(self->logfile, _(" widget: background\n"));
 	} else if (widget == GTK_WIDGET(self->button_rec)) {
-	    g_fprintf(self->logfile, " widget: button_rec\n");
+	    g_fprintf(self->logfile, _(" widget: button_rec\n"));
 	} else if (widget == GTK_WIDGET(self->button_stop)) {
-	    g_fprintf(self->logfile, " widget: button_stop\n");
+	    g_fprintf(self->logfile, _(" widget: button_stop\n"));
 	}
 	fflush(self->logfile);
     }
@@ -790,7 +792,7 @@ on_button_press(GtkWidget* widget, GdkEventButton *button_event, gpointer data)
 
 #ifdef DEBUG
     if (self->logfile) {
-        g_fprintf(self->logfile, "%s -- leave\n", __func__);
+        g_fprintf(self->logfile, _("%s -- leave\n"), __func__);
 	fflush(self->logfile);
     }
 #endif
@@ -806,18 +808,18 @@ on_error(LocationGPSDControl *control, gpointer data)
 #endif
 #ifdef DEBUG
     if (self->logfile) {
-        g_fprintf(self->logfile, "%s -- enter\n", __func__);
+        g_fprintf(self->logfile, _("%s -- enter\n"), __func__);
 	fflush(self->logfile);
     }
 #endif
     if (self->app_state != APP_STATE_IDLE) {
 	hildon_banner_show_information(NULL,
 			NULL,
-			"on_error, going to IDLE state");
+			_("on_error, going to IDLE state"));
 	self->app_state = APP_STATE_IDLE;
 	location_gpsd_control_stop(self->control);
 #ifndef __arm__
-        g_print("on_error : calling update_status_and_buttons\n");
+        g_print(_("on_error : calling update_status_and_buttons\n"));
 #endif
 	update_status_and_buttons(self);
 	logfile_close(self);
@@ -833,7 +835,7 @@ on_start(LocationGPSDControl *control, gpointer data)
 #ifdef DEBUG
     GpsDataLoggerWidget *self = GPS_DATA_LOGGER_WIDGET (data);
     if (self->logfile) {
-        g_fprintf(self->logfile, "%s -- was here\n", __func__);
+        g_fprintf(self->logfile, _("%s -- was here\n"), __func__);
 	fflush(self->logfile);
     }
 #endif
@@ -848,21 +850,21 @@ on_stop(LocationGPSDControl *control, gpointer data)
 #endif
 #ifdef DEBUG
     if (self->logfile) {
-        g_fprintf(self->logfile, "%s -- enter\n", __func__);
+        g_fprintf(self->logfile, _("%s -- enter\n"), __func__);
 	fflush(self->logfile);
     }
 #endif
 	if (self->app_state == APP_STATE_STOPPING) {
         	hildon_banner_show_information(NULL,
 			                       NULL,
-		        	               "on_stop, going to IDLE state");
+		        	               _("on_stop, going to IDLE state"));
 		self->app_state = APP_STATE_IDLE;
 #ifndef __arm__
-                g_print("on_stop : calling update_status_and_buttons\n");
+                g_print(_("on_stop : calling update_status_and_buttons\n"));
 #endif
 #ifdef DEBUG
             if (self->logfile) {
-                g_fprintf(self->logfile, "%s -- going to IDLE, calling update_status_and_buttons\n", __func__);
+                g_fprintf(self->logfile, _("%s -- going to IDLE, calling update_status_and_buttons\n"), __func__);
 	        fflush(self->logfile);
             }
 #endif
@@ -890,11 +892,11 @@ on_changed(LocationGPSDevice *device, gpointer data)
 			if (self->app_state == APP_STATE_STARTING) {
 			    hildon_banner_show_information(NULL,
                                 NULL,
-                                "on_changed, going to RECORDING state");
+                                _("on_changed, going to RECORDING state"));
                   
                             self->app_state = APP_STATE_RECORDING;
 #ifndef __arm__
-                            g_print("on_change : calling update_status_and_buttons\n");
+                            g_print(_("on_change : calling update_status_and_buttons\n"));
 #endif
                             update_status_and_buttons(self);
 	                    self->points_recorded_in_current_segment = 0;
@@ -1160,11 +1162,11 @@ void hw_event_handler(osso_hw_state_t *state, gpointer data)
     if (state->shutdown_ind)
     {
         hildon_banner_show_information(NULL, NULL, 
-                                       "Shutdown event!");
+                                       _("Shutdown event!"));
         should_stop_recording = TRUE;
 #ifdef DEBUG
         if (self->logfile) {
-            g_fprintf(self->logfile, "  Shutdown event!\n");
+            g_fprintf(self->logfile, _("  Shutdown event!\n"));
             fflush(self->logfile);
         }
 #endif
@@ -1172,11 +1174,11 @@ void hw_event_handler(osso_hw_state_t *state, gpointer data)
     if (state->save_unsaved_data_ind)
     {
         hildon_banner_show_information(NULL, NULL, 
-                                       "Must save unsaved data event!");
+                                       _("Must save unsaved data event!"));
         should_stop_recording = TRUE;
 #ifdef DEBUG
         if (self->logfile) {
-            g_fprintf(self->logfile, "  Must save unsaved data event!\n");
+            g_fprintf(self->logfile, _("  Must save unsaved data event!\n"));
             fflush(self->logfile);
         }
 #endif
@@ -1234,7 +1236,7 @@ gps_data_logger_widget_init (GpsDataLoggerWidget * self)
 #endif
         hildon_banner_show_information(NULL,
 			NULL,
-			"osso_initialize failed");
+			_("osso_initialize failed"));
     }
     self->file = NULL;
 #ifdef DEBUG
@@ -1283,7 +1285,7 @@ gps_data_logger_widget_init (GpsDataLoggerWidget * self)
     gtk_event_box_set_visible_window(GTK_EVENT_BOX(self->button_stop), FALSE);
 
     self->gps_status = gtk_image_new();    
-    status_text = gtk_label_new("Status: ");
+    status_text = gtk_label_new(_("Status: "));
 
     hbox_status = gtk_hbox_new (FALSE, 2);
     hbox_buttons = gtk_hbox_new (FALSE, 2);
@@ -1295,7 +1297,7 @@ gps_data_logger_widget_init (GpsDataLoggerWidget * self)
     gtk_box_pack_start (GTK_BOX (vbox), hbox_buttons, FALSE, FALSE, 0);
      
 #ifndef __arm__
-    g_print("init : calling update_status_and_buttons\n");
+    g_print(_("init : calling update_status_and_buttons\n"));
 #endif
     update_status_and_buttons(self);
 
@@ -1374,7 +1376,7 @@ gps_data_logger_widget_init (GpsDataLoggerWidget * self)
         if (result != OSSO_OK)
         {
 #ifndef __arm__
-            g_print("Error setting HW state callback (%d)\n", result);
+            g_print(_("Error setting HW state callback (%d)\n"), result);
 #endif
         }
     }
